@@ -1,6 +1,7 @@
+import gzip
 import requests
 import re
-import gzip
+import bz2
 import shutil
 import os
 from datetime import datetime
@@ -18,22 +19,31 @@ class EPGDownloader:
     def __init__(self, script_dir):
         logging.info("EPG downloader initialised: {0}".format(str(datetime.now())))
         self.script_dir = script_dir
-        self.url = "http://epg.kodibg.org/dl.php"
+        #GZIP format: http://epg.kodibg.org/dl.php
+        self.url = "http://epg.cloudns.org/dl.php"
         self.filename = "epg"
 
     def __donwload(self):
         try:
             logging.info("download started: {0}".format(str(datetime.now())))
-            r = requests.get(self.url, allow_redirects=True)
-            with open(self.script_dir + "/" + self.filename + ".xml.gz", "wb") as f:
-                f.write(r.content) #tuk
-                f.close()
+            filename = self.script_dir + "/" + self.filename + ".xml.gz"
+
+
+            # r = requests.get(self.url, allow_redirects=True)
+            # with open(self.script_dir + "/" + self.filename + ".xml.bz2", "wb") as f:
+            #     f.write(r.content) #tuk
+            #     f.close()
+
+            #workaround due to security constraint from kodibg.org
+            #to fix for windows OS
+            os.system("wget -N --tries=5 http://epg.cloudns.org/dl.php -O " + filename)
         except requests.exceptions.RequestException as err:
             print(err("message"))
             sys.exit(1)
 
     def extract(self):
         self.__donwload()
+
         epgGZipped = self.script_dir + "/" + self.filename + ".xml.gz"
         epg = self.script_dir + "/" + self.filename + ".xml"
 
