@@ -1,6 +1,7 @@
 #!/usr/bin/python
 
-import neterraproxy.wsrv
+#import neterraproxy.wsrv
+import wsrv
 import argparse
 
 parser = argparse.ArgumentParser()
@@ -14,4 +15,4 @@ password = getattr(args, "password")
 app_dir = getattr(args,"app_dir")
 
 
-neterraproxy.wsrv.run(username, password, app_dir)
\ No newline at end of file
+wsrv.run(username, password, app_dir)
\ No newline at end of file
